package com.community.huiju.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.community.commom.mode.ResponseBean;
import com.community.commom.session.UserElement;
import com.community.huiju.dao.BillInvoiceMapper;
import com.community.huiju.dao.BillStatementMapper;
import com.community.huiju.model.Bill;
import com.community.huiju.dao.BillMapper;
import com.community.huiju.model.TpTransaction;
import com.community.huiju.service.IBillService;
import com.google.common.collect.Maps;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;
import java.util.Map;

/**
 * <p>
 * 缴费项表 服务实现类
 * </p>
 *
 * @author weiximei
 * @since 2019-02-13
 */
@Service
public class BillServiceImpl extends ServiceImpl<BillMapper, Bill> implements IBillService {

    /** 缴费项表 **/
    @Autowired
    private BillMapper billMapper;

    /** 缴费单 **/
    @Autowired
    private BillInvoiceMapper billInvoiceMapper;

    /** 账单流水表 **/
    @Autowired
    private BillStatementMapper billStatementMapper;

    @Override
    @Transactional(rollbackFor = Exception.class)
    public ResponseBean updateBillNameAndBillExplainAndEndDate(UserElement userElement, String parameter) {
        ResponseBean responseBean = new ResponseBean();
        Bill bill = JSONObject.parseObject(parameter, Bill.class);
        if (StringUtils.isEmpty(bill.getBillName())) {
            responseBean.addError("收费项名称不能为空");
            return responseBean;
        }
        if (StringUtils.isEmpty(bill.getBillExplain())) {
            responseBean.addError("缴费项说明");
            return responseBean;
        }
        if (bill.getEndDate() == null) {
            responseBean.addError("截止时间不能为空");
            return responseBean;
        }

        Bill selectBill = billMapper.selectById(bill.getId());
        if (selectBill == null) {
            responseBean.addError("缴费项不存在");
            return responseBean;
        }

        billMapper.updateById(bill);
        responseBean.addSuccess("操作成功");
        return responseBean;
    }

    @Override
    public ResponseBean getByBillId(Integer id) {
        ResponseBean responseBean = new ResponseBean();
        Bill bill = billMapper.selectById(id);
        responseBean.addSuccess(bill);
        return responseBean;
    }
    
    /**
     * 获取收费项列表
     *
     * @param bill
     * @param pageNum
     * @param pageSize
     * @return
     */
    @Override
    public ResponseBean getBillList(Bill bill, Integer pageNum, Integer pageSize) {
        ResponseBean responseBean = new ResponseBean();
        Page page = new Page(pageNum,pageSize);
        // 分页查询
        List<Bill> list = billMapper.selectListByParams(page,bill);
        Map<String, Object> map = Maps.newHashMap();
        map.put("list",list);
        map.put("total",page.getTotal());
        responseBean.addSuccess(map);
        return responseBean;
    }
}
